// Copyright (C) 2024 The Android Open Source Project
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.gerrit.server.restapi.config;

import static com.google.gerrit.common.data.GlobalCapability.MAINTAIN_SERVER;

import com.google.gerrit.extensions.annotations.RequiresCapability;
import com.google.gerrit.extensions.restapi.AuthException;
import com.google.gerrit.extensions.restapi.BadRequestException;
import com.google.gerrit.extensions.restapi.ResourceConflictException;
import com.google.gerrit.extensions.restapi.Response;
import com.google.gerrit.extensions.restapi.RestReadView;
import com.google.gerrit.server.config.IndexResource;
import java.util.Map;

@RequiresCapability(MAINTAIN_SERVER)
public class ListIndexVersions implements RestReadView<IndexResource> {

  @Override
  public Response<Map<Integer, IndexInfo.IndexVersionInfo>> apply(IndexResource rsrc)
      throws AuthException, BadRequestException, ResourceConflictException, Exception {
    IndexInfo info = IndexInfo.fromIndexDefinition(rsrc.getIndexDefinition());
    return Response.ok(info.getVersions());
  }
}
